# MedMNIST Pneumonia Dataset

The PneumoniaMNIST is based on a prior dataset of 5,856 pediatric chest X-Ray
images. The task is binary-class classification of pneumonia against normal. The
source training set is split with a ratio of 9:1 into training and validation
set, and use its source validation set as the test set. The source images are
gray-scale, and their sizes are (384–2,916) × (127–2,713). The images are
center-cropped with a window size of length of the short edge and resized into 1
× 28 × 28.
